@@ -458,7 +458,7 @@ class Experiment(object):
                         self.run_configs[0]['scattering_surface']
                     )
                     assert np.all(E_reco_prot == E_max) and np.all(E_reco == E_max), \
-                        'To compute effective area ratio, the true_energy bins must be the same'
+                        'To compute effective area ratio, the energy bins must be the same'
 
                     self.ax_eff_area_ratio.plot(E_reco[:-1], S_reco / S_max,
                                                 label=self.name + '_ratio_gamma',
@@ -600,7 +600,7 @@ class Experiment(object):
         if 'reco_altitude' in self.data and 'reco_azimuth' in self.data:
             self.visibility_angular_resolution_plot(visible)
             self.visibility_angular_resolution_reco_plot(visible)
-        if 'true_energy' in self.data:
+        if 'reco_energy' in self.data:
             self.visibility_energy_resolution_plot(visible)
             self.visibility_energy_resolution_reco_plot(visible)
         if 'reco_impact_x' in self.data and 'reco_impact_y' in self.data:
@@ -638,8 +638,8 @@ class Experiment(object):
             ax.axis('equal')
             ax.set_xlim(mc.min(), mc.max())
             ax.set_ylim(mc.min(), mc.max())
-            ax.set_xlabel('True true_energy [log(E/TeV)]')
-            ax.set_ylabel('Reco true_energy [log(E/TeV)]')
+            ax.set_xlabel('True energy [log(E/TeV)]')
+            ax.set_ylabel('Reco energy [log(E/TeV)]')
             ax.set_title(self.name)
         return ax
 
@@ -764,7 +764,7 @@ def plot_migration_matrices(exp, colorbar=True, **kwargs):
     if 'figsize' not in kwargs:
         kwargs['figsize'] = (25, 5)
     fig, axes = plt.subplots(1, 5, **kwargs)
-    if 'true_energy' in exp.data:
+    if 'reco_energy' in exp.data:
         axes[0] = exp.plot_energy_matrix(ax=axes[0], colorbar=colorbar)
     if 'reco_altitude' in exp.data:
         axes[1] = exp.plot_altitude_matrix(ax=axes[1], colorbar=colorbar)
@@ -861,7 +861,7 @@ def plot_exp_on_fig(exp, fig):
     if 'reco_altitude' in exp.data and 'reco_azimuth' in exp.data:
         exp.plot_angular_resolution(ax=ax_ang_res)
         exp.plot_angular_resolution_reco(ax=ax_ang_res)
-    if 'true_energy' in exp.data:
+    if 'reco_energy' in exp.data:
         exp.plot_energy_resolution(ax=ax_ene_res)
         exp.plot_energy_resolution_reco(ax=ax_ene_res)
     if 'reco_impact_x' in exp.data and 'reco_impact_y' in exp.data:
@@ -1004,7 +1004,7 @@ def create_update_gammaness_cut(experiments_dict, fig_resolution, visible_experi
 
         if 'reco_altitude' in exp.data and 'reco_azimuth' in exp.data:
             exp.update_angular_resolution_reco(ax_ang_res)
-        if 'true_energy' in exp.data:
+        if 'reco_energy' in exp.data:
             exp.update_energy_resolution_reco(ax_ene_res)
         if 'reco_impact_x' in exp.data and 'reco_impact_y' in exp.data:
             exp.update_impact_resolution_reco(ax_imp_res)
